@@ -23,32 +23,39 @@
 #include "core/course.h"
 #include "core/resourcemanager.h"
 #include "core/resources/courseresource.h"
-
 #include <QAbstractListModel>
+#include "artikulate_debug.h"
 #include <QSignalMapper>
-
-#include <KLocale>
-#include <KDebug>
+#include <KLocalizedString>
 
 CourseModel::CourseModel(QObject *parent)
     : QAbstractListModel(parent)
-    , m_resourceManager(0)
-    , m_language(0)
+    , m_resourceManager(nullptr)
+    , m_language(nullptr)
     , m_signalMapper(new QSignalMapper(this))
+{
+    connect(m_signalMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
+            this, &CourseModel::emitCourseChanged);
+    connect(this, &CourseModel::resourceManagerChanged,
+            this, &CourseModel::rowCountChanged);
+    connect(this, &CourseModel::languageChanged,
+            this, &CourseModel::rowCountChanged);
+}
+
+CourseModel::~CourseModel()
+{
+
+}
+
+QHash< int, QByteArray > CourseModel::roleNames() const
 {
     QHash<int, QByteArray> roles;
     roles[TitleRole] = "title";
     roles[DescriptionRole] = "description";
     roles[IdRole] = "id";
     roles[DataRole] = "dataRole";
-    setRoleNames(roles);
-
-    connect(m_signalMapper, SIGNAL(mapped(int)), SLOT(emitCourseChanged(int)));
-}
-
-CourseModel::~CourseModel()
-{
 
+    return roles;
 }
 
 void CourseModel::setResourceManager(ResourceManager *resourceManager)
@@ -66,18 +73,17 @@ void CourseModel::setResourceManager(ResourceManager *resourceManager)
     m_resourceManager = resourceManager;
     m_resources.clear();
     if (m_resourceManager) {
-        connect(m_resourceManager, SIGNAL(courseResourceAboutToBeAdded(CourseResource*,int)),
-                SLOT(onCourseResourceAboutToBeAdded(CourseResource*,int)));
-        connect(m_resourceManager, SIGNAL(courseResourceAdded()),
-                SLOT(onCourseResourceAdded()));
-        connect(m_resourceManager, SIGNAL(courseResourceAboutToBeRemoved(int)),
-                SLOT(onCourseResourceAboutToBeRemoved(int)));
+        connect(m_resourceManager, &ResourceManager::courseResourceAboutToBeAdded,
+                this, &CourseModel::onCourseResourceAboutToBeAdded);
+        connect(m_resourceManager, &ResourceManager::courseResourceAdded,
+                this, &CourseModel::onCourseResourceAdded);
+        connect(m_resourceManager, &ResourceManager::courseResourceAboutToBeRemoved,
+                this, &CourseModel::onCourseResourceAboutToBeRemoved);
     }
     if (m_language && m_resourceManager) {
         m_resources = m_resourceManager->courseResources(m_language);
     }
     endResetModel();
-
     emit resourceManagerChanged();
 }
 
@@ -101,6 +107,7 @@ void CourseModel::setLanguage(Language *language)
     }
     emit languageChanged();
     emit endResetModel();
+    emit rowCountChanged();
 }
 
 QVariant CourseModel::data(const QModelIndex& index, int role) const
@@ -161,6 +168,7 @@ void CourseModel::onCourseResourceAdded()
 {
     updateMappings();
     endInsertRows();
+    emit rowCountChanged();
 }
 
 void CourseModel::onCourseResourceAboutToBeRemoved(int index)
@@ -172,12 +180,13 @@ void CourseModel::onCourseResourceAboutToBeRemoved(int index)
     int modelIndex = m_resources.indexOf(originalResource);
 
     if (modelIndex == -1) {
-        kWarning() << "Cannot remove course from model, not registered";
+        qCWarning(ARTIKULATE_LOG) << "Cannot remove course from model, not registered";
         return;
     }
     beginRemoveRows(QModelIndex(), modelIndex, modelIndex);
     m_resources.removeAt(modelIndex);
     endRemoveRows();
+    emit rowCountChanged();
 }
 
 void CourseModel::emitCourseChanged(int row)
@@ -200,7 +209,7 @@ QVariant CourseModel::headerData(int section, Qt::Orientation orientation, int r
 void CourseModel::updateMappings()
 {
     if (!m_language) {
-        kDebug() << "Aborting to update mappings, language not set.";
+        qCDebug(ARTIKULATE_LOG) << "Aborting to update mappings, language not set.";
         return;
     }
     int courses = m_resources.count();
